{
  pkgs,
  config,
  user,
  home,
}:
{
  home = {
    username = user.name;
    homeDirectory = user.home;
    stateVersion = config.system.stateVersion;
    sessionVariables = {
      XCOMPOSECACHE = "${home.xdg.cacheHome}/X11/xcompos";
      XAUTHORITY = "$XDG_RUNTIME_DIR/Xauthority";
      ANDROID_HOME = "${home.xdg.dataHome}/android";
      CUDA_CACHE_PATH = "${home.xdg.cacheHome}/nv";
      GRADLE_USER_HOME = "${home.xdg.dataHome}/gradle";
      KODI_DATA = "${home.xdg.dataHome}/kodi";
      _JAVA_OPTIONS = "-Djava.util.prefs.userRoot=${home.xdg.configHome}/java";
      WINEPREFIX = "${home.xdg.dataHome}/wine";
    };
  };

  programs = {
    lazygit.enable = true;
    git = {
      enable = true;
      package = pkgs.git;
      extraConfig = {
        core = {
          whitespace = [
            "blank-at-eol"
            "blank-at-eof"
            "space-before-tab"
          ];
        };
      };
    };
    direnv = {
      enable = true;
      nix-direnv.enable = true;
    };
    gpg = {
      enable = true;
      homedir = "${home.xdg.dataHome}/gnupg";
    };
  };
  xdg = {
    enable = true;
    mime.enable = true;
    cacheHome = "${home.home.homeDirectory}/.cache";
    configHome = "${home.home.homeDirectory}/.config";
    dataHome = "${home.home.homeDirectory}/.local/share";
    stateHome = "${home.home.homeDirectory}/.local/state";
    userDirs = {
      enable = true;
      createDirectories = true;
      desktop = "${home.home.homeDirectory}/Desktop";
      documents = "${home.home.homeDirectory}/Documents";
      download = "${home.home.homeDirectory}/Downloads";
      music = "${home.home.homeDirectory}/Music";
      pictures = "${home.home.homeDirectory}/Pictures";
      publicShare = "${home.home.homeDirectory}/Public";
      templates = "${home.home.homeDirectory}/Templates";
      videos = "${home.home.homeDirectory}/Videos";
    };
  };
}
